class BaseNotifier(object):
  """docstring for BaseNotifier"""
  def __init__(self, title):
    super(BaseNotifier, self).__init__()

  def notify(self, message, title):
    pass

class OSXNotifier(BaseNotifier):
  def __init__(self, title=u''):
    super(OSXNotifier, self).__init__(title)
    from pync import Notifier
    self._nc = Notifier

  def notify(self, message, title):
    self._nc.notify(message, title=title)

class UbuntuNotifier(BaseNotifier):
  def __init__(self, title=u''):
    super(UbuntuNotifier, self).__init__(title)
    import pynotify
    pynotify.init(u'tosu')
    self._nc = pynotify.Notification('')

  def notify(self, message, title=None):
    self._nc.update(message)
    self._nc.show()



# -*- coding: utf-8 -*- 

import urwid
import logging
import time
from urwid.util import move_next_char
from urwid.widget import LEFT, SPACE

from todo import Todo

# Vi mode Edit box
class ViEdit(urwid.Edit):
  CMD_MODE = 0
  INPUT_MODE = 1

  def __init__(self, caption=u'', edit_text=u'', multiline=False,
          align=LEFT, wrap=SPACE, allow_tab=False,
          edit_pos=None, layout=None, mask=None, 
          app=None, timeout=0.7, last_press=598233600,
          mode=CMD_MODE):

    # additional stuff 
    self.mode = mode 
    self.timeout = timeout
    self.last_press = last_press
    self.key_buf = []
    self.j_pressed = last_press 
    self._app = app
    super(ViEdit, self).__init__(caption, edit_text, multiline,
           align, wrap, allow_tab,
           edit_pos, layout, mask)

    self.origin_keypress = self.keypress

    if mode == ViEdit.CMD_MODE:
      self.keypress = self.cmd_keypress
    else:
      self.mode = ViEdit.INPUT_MODE
      self._app.footer.set_text(u'-- INSERT --')

  def get_app(self):
    return self._app

  def cmd_keypress(self, size, key):
    # Step 1.
    # timeout 
    if time.time() - self.last_press > self.timeout:
      self.key_buf = []
      self.key_buf.append(key)
      self.last_press = time.time()

    else:
      self.key_buf.append(key)
      self.last_press = time.time()

    # print key pressed in mode bar
    # self._app.display(self.key_buf[-10:])

    # Step 2.
    if key == 'i':
      self.mode = ViEdit.INPUT_MODE
      self._app.footer.set_text(u'-- INSERT --')
      # key control shift
      self.keypress = self.origin_keypress

    elif key == 'a':
      pos = self.get_cursor_coords(size)
      self.move_cursor_to_coords(size, pos[0] + 1, pos[1])
      self.mode = ViEdit.INPUT_MODE
      self._app.footer.set_text(u'-- INSERT --')
      # key control shift
      self.keypress = self.origin_keypress

    elif key == 'esc':
      # in cmd mode just clear key buffer
      self._app.display(u'')
      self._app.footer.set_text(u'')
      self.key_buf = []

    elif key == 'k' or key == 'up':
      # up 
      pos = self.get_cursor_coords(size)
      self.move_cursor_to_coords(size, pos[0], pos[1] - 1)

    elif key == 'j' or key == 'down':
      # down 
      pos = self.get_cursor_coords(size)
      self.move_cursor_to_coords(size, pos[0], pos[1] + 1)

    elif key == 'h' or key == 'left':
      # left 
      pos = self.get_cursor_coords(size)
      self.move_cursor_to_coords(size, pos[0] - 1, pos[1])

    elif key == 'l' or key == 'right':
      # right 
      pos = self.get_cursor_coords(size)
      self.move_cursor_to_coords(size, pos[0] + 1, pos[1])

    elif key == 'w':
      pass

    elif key == 'b':
      pass

    elif key == '$':
        pos = self.get_cursor_coords(size)
        x_pos = pos[0] + 1
        self.move_cursor_to_coords(size, x_pos, pos[1])

        while x_pos == self.get_cursor_coords(size)[0]:
          x_pos = x_pos + 1
          self.move_cursor_to_coords(size, x_pos, pos[1])

    elif key == '^' or key == '0':
        pos = self.get_cursor_coords(size)
        self.move_cursor_to_coords(size, 0, pos[1])

    elif key == 'G' :
        pos = self.get_cursor_coords(size)
        y_pos = pos[1] + 1
        self.move_cursor_to_coords(size, 0, y_pos)

        while y_pos == self.get_cursor_coords(size)[1]:
          y_pos = y_pos + 1
          self.move_cursor_to_coords(size, 0, y_pos)

    elif key == 'g' and len(self.key_buf) > 1 and self.key_buf[-2] == 'g':
        self.move_cursor_to_coords(size, 0, 1)

    elif key == 'x':
        p = self.edit_pos
        if p >= len(self.edit_text):
          return key
        p = move_next_char(self.edit_text, p, len(self.edit_text))
        self.set_edit_text( self.edit_text[:self.edit_pos] 
            + self.edit_text[p:] )
    else:
      # return key to be handled by mainloop 
      return key

  def keypress(self, size, key):
    
    if key == 'esc': # 1. Change mode
      pos = self.get_cursor_coords(size)
      self.move_cursor_to_coords(size, pos[0] - 1, pos[1])
      # clear buffer
      self.key_buf = []
      self.mode = ViEdit.CMD_MODE
      self._app.footer.set_text(u'')
      # key control shift
      self.origin_keypress = self.keypress
      self.keypress = self.cmd_keypress
    elif key == 'j':
      # jk -> esc -> enter cmd mode 
      self.j_pressed = time.time()
    elif key == 'k':
      # jk -> esc -> enter cmd mode 
      if (time.time() - self.j_pressed) < 0.2:
        self.keypress(size, 'esc')
      else:
        return super(ViEdit, self).keypress(size, key) 
    else:
      return super(ViEdit, self).keypress(size, key) 

class TodoPile(urwid.Pile):
  def __init__(self, widget_list, focus_item=None, app=None):
    self._app = app
    super(TodoPile, self).__init__(widget_list, focus_item)

class TodoEdit(ViEdit):
  FOCUS = 'footer'
  NORMAL = 'body'

  # hook to app.get_todo_focus
  def get_pile_focus(self):
    # int
    return self._app.get_todo_focus()

  # hook to app.set_todo_focus
  def set_pile_focus(self, i):
    # int
    return self._app.set_todo_focus(i)
      
  # change is style of an item is todo_pile when selected
  def set_attr_for(self, i, attr=FOCUS):
    # i int, attr string
    # TODO check bound
    self._app.todo_pile.widget_list[i].set_attr(attr)

  # check bound for function select
  def get_todo_length(self):
    return len(self._app.todo_pile.widget_list)

  def select(self, direction):
    # direction = 1 down, -1 up
    # get cur_focus item
    cur = self.get_pile_focus()
    if cur == 0 and (cur + direction) >= 0 \
        and (cur + direction) < self.get_todo_length():
      cur += direction # update 
      self.set_attr_for(cur) # cur is updated
      self.set_pile_focus(cur) # save this value back to app obj
      self.pre = cur 

    # > 0 is because 0, TodoEdit field, doesn't need highlight
    elif cur !=0 and (cur + direction) > 0 \
        and (cur + direction) < self.get_todo_length():
      self.set_attr_for(self.pre, 'body')
      cur += direction # update 
      self.set_attr_for(cur) # cur is updated
      self.set_pile_focus(cur) # save this value back to app obj
      self.pre = cur 

  def cmd_keypress(self, size, key):
    if key == 'i':
      self._app.footer.set_text(u'-- INSERT --')
      self.keypress = self.origin_keypress
      # added bellow
      if hasattr(self, 'pre'):
        self.set_attr_for(self.pre, 'body')
        self.set_pile_focus(0) # will start from item 1 next time
    elif key == 'esc':
      self._app.display(u'')
      self._app.footer.set_text(u'')
      self.key_buf = []
      # added bellow
      return key
    elif key == 'k':
      self.select(-1) 
    elif key == 'j':
      self.select(1) 
    elif key == 'enter' and not ':' in self.key_buf:
      # toggle alarms.
      if self._app._timer_handle == None:
        # 1. Fresh start
        cur = self.get_pile_focus()
        if cur != 0:
          self._app.footer.set_text(u'Task Started...')
          self._app.set_alarm()
      elif self._app._timer_handle != None:
        # 2. re-start
        self._app.remove_clock_alarm()
        self._app.footer.set_text(u'Task Re-Started...')
        self._app.set_alarm()
      else:
        # TODO 3. pause and resume
        pass
    elif key == ' ' and not ':' in self.key_buf:
      cur = self.get_pile_focus()
      if cur != 0:
        view = self._app.todo_pile.widget_list[cur]
        view.toggle_done()
        # TODO sort todo and done task
       
    elif key == 'backspace' and not ':' in self.key_buf:
      self._app.remove_clock_alarm()
    else:
      return super(TodoEdit, self).cmd_keypress(size, key) 

  def keypress(self, size, key):
    if key == 'enter':
      # Create obj 
      unit = self.edit_text.lstrip().split(u' ')[0]

      if unit.isdigit():
        start_index = self.edit_text.find(unit) + len(unit)
        content = self.edit_text[start_index:].strip()
        unit = int(unit)
      else:
        content = self.edit_text.strip()
        unit = 0

      # TODO Order app.todos and Order views
      todo_obj = Todo(unit, content)
      self._app.todos.append(todo_obj)
        
      # Update UI
      new_view_item = urwid.AttrWrap(TodoItem(str(todo_obj), data=todo_obj), 'body')

      # 0 is the input field
      self._app.todo_pile.widget_list.insert(1, new_view_item)
      self.set_edit_text(u'')

    elif key == 'shift enter':
      self.insert_text(u'\n')
    else:
      return super(TodoEdit, self).keypress(size, key) 

class TodoItem(urwid.Text):

  # overwrite
  def __init__(self, markup, align=LEFT, wrap=SPACE, layout=None, data=None,):
    # data obj
    if data:
      self.set_obj(data)
    super(TodoItem, self).__init__(markup, align=LEFT, wrap=SPACE, layout=None)

  # TODO make this more usefull.   progress 1/3

  def selectable(self):
    return True
 
  def get_obj(self):
    if hasattr(self, 'obj'):
      return self.obj
    else:
      return None

  def toggle_done(self):
    # this will change data status first and also change UI
    if self.get_obj():
      self.get_obj().toggle_done()
    else:
      return

  def update_time(self):
    self.obj.update_time()
    self._change_mark()

  def _change_mark(self):
    # call chain started from toggle_done, then called from data binded
    self.set_text(str(self.obj))

  def set_obj(self, obj):
    self.obj = obj
    obj.view = self

  def keypress(self, size, key):
    return key





import subprocess
from sys import platform
import os
import logging

def play_sound(audio_file):
  audio_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'sound_effects', audio_file) 
  if platform == "darwin":  
    p = subprocess.Popen(["afplay", audio_file])
  elif platform == "linux2":
    p = subprocess.Popen(["aplay", audio_file, "-q"])
#  p.terminate()

def main():
  """docstring for main"""
  play_sound('paper.wav')

if __name__ == '__main__':
  main()



# -*- coding: utf-8 -*- 

# when using py2app, this includes a lot of packages
import os
import sys
import time
import urwid 
import pickle
import logging
import datetime
import ConfigParser

from sys import platform
from threading import Timer

from summary import Summary
from todo import Todo
from widgets import ViEdit
from widgets import TodoEdit
from widgets import TodoItem
from sound import play_sound
from notifier import OSXNotifier, UbuntuNotifier

# static util functions
def last(n, li):
  # take a list return a string
  if n > 0 and n <= len(li):
    return ''.join(li[-1*n:])
  else:
    return ''

class MyUnpickler(pickle.Unpickler): 
  def find_class(self, module, name):
    if module == 'todo' and name == 'Todo':
      return Todo 
    else:
      return pickle.Unpickler.find_class(self, module, name)

class App:
  def __init__(self, dir='./', work_mins=25, rest_mins=5):
    self._dir = dir
    self._work_mins = work_mins
    self._rest_mins = rest_mins

    # Two Models App deals with
    self.todos = None
    self.summary = None

    if platform == 'darwin':
      self._nc = OSXNotifier() 
    elif platform == 'linux2':
      self._nc = UbuntuNotifier()
    else:
      self._nc = None

    self.init_ui()

    palette = [
        ('body','dark blue', '', 'standout'),
        ('footer','light red', '', 'black'),
        ('header','light blue', 'black'),
        ('select','light red', '', 'black'),
    ]

    # set main loop
    self.loop = urwid.MainLoop(self.frame, palette, unhandled_input=self.app_keypress)

    # Store alarm handles
    self._timer_handle = None
    # you don't break until you finish a task
    self._break = False

  def init_logger(self):
    # init logger
    # TODO get name, instead of hardcode
    logger = logging.getLogger('tosu')
    # TODO path should be defined in cfg file
    hdlr = logging.FileHandler('./tosu.log')
    formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
    hdlr.setFormatter(formatter)
    logger.addHandler(hdlr) 
    logger.setLevel(logging.DEBUG)

    logger.debug('init ok')

  def init_models(self):
    pass

  def init_ui(self):
    # reusable widges
    self.divider = urwid.Divider(u'-');

    # header 
    header_text = u'Summary' 
    self.header = urwid.AttrWrap(urwid.Text(u'Editing: %s\n' % header_text), 'header')

    # footer_pile = footer + txt
    self.footer = urwid.Text(u'')
    self.txt = urwid.Text(u'') # display
    self.footer_pile = urwid.AttrWrap(urwid.Pile( [self.txt, self.footer] ), 'footer')

    # Summary
    # summary_fill can be frame.body, option 1
#    self.summary_edit = ViEdit(u'Summary:\n', multiline=True, app=self)
#    self.summary_edit2 = ViEdit(u'Summary2:\n', multiline=True, app=self)
    self.summary_pile = urwid.Pile([])
    self.summary_fill = urwid.Filler(self.summary_pile, 'top')

    # Todos 
    # todo_fill can be frame.body, option 2
    self.todos = []
    self.todos_view = []

    self._pickle_file = os.path.join(self._dir, 'tosu_data.pickle')
    if os.path.exists(self._pickle_file):
      #self.todos = pickle.load(open(self._pickle_file, 'rb'))
      self.todos = MyUnpickler(open(self._pickle_file)).load() 

    for obj in reversed(self.todos):
      if obj._done == False:
        new_view_item = urwid.AttrWrap(TodoItem(str(obj), data=obj), 'body')
        self.todos_view.append(new_view_item)

    # mode = 1, insert mode
    self.todo_edit = TodoEdit(caption=u'Todo:\n>>> ', multiline=False, mode=1, app=self)

    # TODO change this pile, need to change many parts
    self.todos_view.insert(0, self.todo_edit)
    self.todo_pile = urwid.Pile(self.todos_view, focus_item=0)
    self.todo_fill = urwid.Filler(self.todo_pile, 'top')

    # TODO chose which view to show first in cfg file
    self.frame = urwid.AttrWrap(urwid.Frame(self.todo_fill, header=self.header, footer=self.footer_pile), 'body')

    # used by TodoEdit in widgets.py
    self._todo_focus = 0 # focus todo_edit at first place

  def get_todo_focus(self):
    # used by TodoEdit in widgets.py
    return self._todo_focus

  def set_todo_focus(self, i):
    # used by TodoEdit in widgets.py
    self._todo_focus = i

  def run(self):
    self.todo = Todo(app=self)
    self.summary = Summary(app=self, dirname=self._dir)
    self.header.set_text(self.summary.filepath)
    self.loop.run()

  def display(self, something):
    self.txt.set_text(u'Display: ' + str(something))

  def app_keypress(self, key):
    # 1. Check Body = ?
    if self.frame.get_body() == self.todo_fill:
      target = self.todo_edit
      t = 'todo'
    elif self.frame.get_body() == self.summary_fill:
      target = self.summary_pile.focus_item
      t = 'summary'
    else:
      return 

    # 2. Handle
    if key == 'esc':
      pass
    elif key == 'tab':
      cur = self.summary_pile.focus_position
      summary_pile_len = len(self.summary_pile.widget_list)

      if cur == summary_pile_len - 1:
        self.summary_pile.focus_position = 0
      else:
        self.summary_pile.focus_position = cur + 1

    elif key == 'enter':
      command = target.key_buf[:-1] # pop the 'enter' key
      target.key_buf = []
      # self.display(command)

      if last(2, command) == ':q': 
        raise urwid.ExitMainLoop()

      if last(2, command) == ':w': 
        self.update(t)
        self.save(t)

      if last(2, command) == ':x' or last(3, command) ==  ':wq': 
        self.update(t)
        self.save(t)
        time.sleep(0.2) # flash the message 
        raise urwid.ExitMainLoop()

      if last(3, command) == ':to' or last(2, command) == ':t':
        self.update(t)
        self.save(t)
        self.frame.set_body(self.todo_fill)
        self.todo_edit.keypress = self.todo_edit.cmd_keypress

      if last(3, command) == ':su' or last(2, command) == ':s':
        self.update(t)
        self.save(t)
        ViEdit(u'Summary2:\n', multiline=True, app=self)
        new_text = u'\n'.join([str(todo_task).decode('utf8') for todo_task in self.todos if todo_task._done == True])

        summary_list = []
        for todo_task in self.todos:
          if todo_task._done: 
            summary_list.append(ViEdit(todo_task.content + '\n', multiline=True, app=self))

        self.summary_pile = urwid.Pile(summary_list)
        self.summary_fill = urwid.Filler(self.summary_pile, 'top')
        self.frame.set_body(self.summary_fill)
        #self.summary_edit.keypress = self.summary_edit.cmd_keypress
    # End elif 'enter'
  # End func

  def update(self, t=None):
    if t == None:
      return
    elif t == 'summary':
      content = u'\n\n'.join([su.edit_text for su in self.summary_pile.widget_list])
      self.summary.set_content( content )
    elif t == 'todo':
      pass

  def save(self, t=None):
    if t == None:
      return
    elif t == 'summary':
      filepath = self.summary.save_md()
      self.footer.set_text(u'Summary saved to: %s' % filepath)
    elif t == 'todo':
      self.footer.set_text(u'todo saved')

      for item in self.todos:
        item.view = None

      pickle.dump(self.todos, open(self._pickle_file, 'wb'))

  def set_alarm(self):
    # Read mins from config file
    if not self._work_mins:
      sec = 25 * 60
    else:
      sec = self._work_mins * 60

    logger = logging.getLogger('tosu')

    # starting sound effect & notification
    # the dict is passed into callback: self.alarm
    play_sound('scifi_start.wav')
    if self._nc:
      self._nc.notify('A task [name] has started', title='todo-summary')

    self._m1 = sec * 1 /3 
    self._m2 = sec * 2 /3 
    self._timer_handle = self.loop.set_alarm_in(0, self.timer, sec)

    # TODO 
    # 5. Add time, minuste time, move to next task 

  def remove_clock_alarm(self):
    self.footer.set_text(u'Timer stopped.')
    self.loop.remove_alarm(self._timer_handle)
    self._timer_handle = None

  def clock_tick(self, time_left):
    # refresh display
    self.display( str(datetime.timedelta(seconds=time_left))[2:] )

  def timer(self, loop, sec):
    # count down timer, it is a callback.
    # When called, it will register itself to be called after 1 sec.
    if sec == 0:
      self.clock_tick(sec)
      self._timer_handle = None

      if not self._break:
        # Start break timer
        cur = self.get_todo_focus()
        if cur != 0:
          view = self.todo_pile.widget_list[cur]
          view.update_time()

        if self._nc:
          self._nc.notify('Time to break', title='todo-summary')
        # TODO make sound in cfg
        play_sound('horn.wav')
        self.footer.set_text('Coffee time...')

        self._m1 = None
        self._m2 = None
        self._break = True
        # Start break timer
        self._timer_handle = self.loop.set_alarm_in(1, self.timer, self._rest_mins * 60) 
      else:
        # break stop
        # TODO play a different sound
        self._break = False
        if self._nc:
          self._nc.notify('Break done', title='todo-summary')
        play_sound('paper.wav')

      logger = logging.getLogger('tosu')
      logger.debug('timer exit')
      return
    else:
      self.clock_tick(sec)

      # TODO make sound in cfg
      if sec == self._m1 or sec == self._m2:
        play_sound('paper.wav')

      logger = logging.getLogger('tosu')
      logger.debug('timer')
      # save handle for the newly set alarm in app
      self._timer_handle = self.loop.set_alarm_in(1, self.timer,  sec-1) 

# End of App
def main():
  config = ConfigParser.ConfigParser()
  config_file = os.path.expanduser('~/.tosuconf')

  dir = os.path.expanduser('~/Desktop')
  work_mins = 25
  rest_mins = 5

  if os.path.exists(config_file):
    config.read(config_file)
    try:
      temp_dir = config.get('tosu', 'dir')
      if os.path.isdir(temp_dir):
        dir = temp_dir
      work_mins = config.getint('tosu', 'work_mins')
      rest_mins = config.getint('tosu', 'rest_mins')
    except ConfigParser.NoSectionError, ConfigParser.NoOptionError:
      pass
      #print 'using default'

  app = App(dir, work_mins, rest_mins)
  app.run()

if __name__ == '__main__':
  main()




import json
import datetime
import os

class Summary(object):
  """docstring for Summary"""

  def __init__(self, app=None, content=u'', tag=[], dirname=None ):
    super(Summary, self).__init__()
    self._app = app # a handle to editor
    self._tag = tag # a list
    self._content = content
    self._created = datetime.datetime.now()
    self._dirname = dirname
    filename = '%s.md' % self._created.strftime('%Y_%m_%d')
    self._filepath = os.path.join(self._dirname, filename)

    #if os.path.exists(self._filepath):
    #  self._exists = True
    #  self.load_from(self._filepath)
    #else:
    #  self._exists = False

  def set_tag(self, tag):
    self._tag = tag

  def set_content(self, content):
    self._content = content

  def load_from(self, filepath):
    load_tag = False
    load_content = False

    tag_line = []
    content_lines = []
    with open(filepath, 'r') as f:
      for line in f.readlines():
        line = line.strip()

        if load_content and line and line[0] != '-':
          content_lines.append(line)
        if load_tag and line and line[0] != '-':
          tag_line.append(line)
          load_tag = False

        if line == 'tag:':
          load_tag = True
        if line == 'content:':
          load_content = True

    self._tag = u' '.join(tag_line)
    self._content = u'\n'.join(content_lines)

    if self._app:
      self._app.summary_edit.set_edit_text(self._tag + u'\n\n' + self._content)
        
  @property
  def filepath(self):
    return self._filepath

  def to_json(self, pretty=None):
    if pretty:
      pretty = 4

    d = {}
    d['created'] = self._created.strftime('%d_%m_%Y')
    d['tag'] = self._tag
    d['content'] = self._content
    return json.dumps(d, indent=pretty, separators=(',',': '))

  def set_content_from(self, raw_content):
    # raw_content contains both tag and content

    content = []
    tag = []
    for line in raw_content.split('\n'):
      words = line.split(' ')
      # a line must have both tag and content TODO, correct it
      if len(words) > 0 and len(words[0].strip()) >0 and words[0].strip()[0] == ':':
        tag.append(words[0])
        content.append(u' '.join(words[1:]))

    self.set_content( u'\n'.join(content) )
    self.set_tag( u', '.join(tag) )

  def save_md(self):
    with open(self.filepath, 'w') as f:
      f.write(self._content)
    return 'saved to file %s' % format(self._filepath)
 
  def save_pickle(self, tag='', content=''):
    pass



# -*- coding: utf-8 -*-
import datetime 

class Todo(object):
  """Task class"""

  def __init__(self, time_unit=0, content=u'', app=None):
    super(Todo, self).__init__()

    # datetime obj
    self._created = datetime.datetime.now()
    self._done_date = None 

    # integer
    self._time_unit = time_unit
    self._done_unit = 0 

    # over time
    self._ot = 0

    # done time
    self._dt = 0

    # text
    self.content = content

    self.view = None

    self._done = False

  def toggle_done(self):
    # toggle binded TodoItem in UI
    if self._done:
      self._done = False
      self._done_date = None
    else:
      self._done = True
      self._done_date = datetime.datetime.now()
    self.view._change_mark()
    
  def days_passed(self): 
    # delta, datetime.timedelta obj
    delta = date.datetime.now() - self._created
    # return days passed
    return delta.days

  def update_time(self):
    self._done_unit += 1

  def to_edit(self):
    title = self.content 
    return title

  @property
  def mark(self):
    if self._done:
      return u'✓'
    else:
      return u'*'

  def __unicode__(self):
    percent = (u' %d/%d' % (self._done_unit, self._time_unit)).ljust(5)
    
    return u' %s %s %s' % (self.mark, percent, self.content)

  def __str__(self):
    return unicode(self).encode('utf-8')





import todo_summary

try:
  from setuptools import setup
except ImportError:
  from distutils.core import setup

setup(
    name='todo-summary',
    version=todo_summary.__version__,
    author="Ruoran Wang",
    author_email='dashuiwa@gmail.com',
    url='http://pypi.python.org/pypi/todo-summary/',
    packages=['todo_summary', 'todo_summary.test'],
    package_data={'todo_summary': ['sound_effects/*.wav']},
    py_modules = ['todo_summary.todo'],
    scripts=['bin/tosu'],
    license=open('LICENSE.txt').read(),
    description='todo-summary simply combines todo and summary.',
    long_description=open('README.md').read(),
    install_requires=[
      'urwid >= 1.0.0',
      'pync >= 1.0'
    ],
)
